# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/project/role/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/project/role/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Project\\Role\\": "packages/project/role/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Project\Role\Providers\RoleServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Role'  => Project\Role\Facades\Role::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Project\\RoleTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Project\Role\Providers\RoleServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Project\Role\Providers\RoleServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Project\Role\Providers\RoleServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/role/{modulename}

**User**

    http://path-to-route-folder/user/role/{modulename}

**Public**

    http://path-to-route-folder/roles


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/role/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/role/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/role/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/role/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/role/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/role/{modulename}/{slug}
    METHOD: GET