<?php

namespace Project\Role\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Project\Role\Http\Requests\PermissionRequest;
use Project\Role\Interfaces\PermissionRepositoryInterface;
use Project\Role\Models\Permission;
use Project\Role\Forms\Permission as Form;

/**
 * APIController  class for permission.
 */
class PermissionAPIController extends BaseController
{

    /**
     * Initialize permission resource controller.
     *
     * @param type PermissionRepositoryInterface $permission
     *
     * @return null
     */
    public function __construct(PermissionRepositoryInterface $permission)
    {
        parent::__construct();
        $this->repository = $permission;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Project\Role\Repositories\Criteria\PermissionResourceCriteria::class);
    }

    /**
     * Display a list of permission.
     *
     * @return Response
     */
    public function index(PermissionRequest $request)
    {
        return $this->repository
            ->setPresenter(\Project\Role\Repositories\Presenter\PermissionPresenter::class)
            ->paginate();
    }

    /**
     * Display permission.
     *
     * @param Request $request
     * @param Model   $permission
     *
     * @return Response
     */
    public function show(PermissionRequest $request, Permission $permission)
    {
        return $permission->setPresenter(\Project\Role\Repositories\Presenter\PermissionListPresenter::class);
        ;
    }

    /**
     * Create new permission.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PermissionRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('role::permission.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('role/permission/' . $permission->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('role/permission');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the permission.
     *
     * @param Request $request
     * @param Model   $permission
     *
     * @return Response
     */
    public function update(PermissionRequest $request, Permission $permission)
    {
        try {
            $data = $request->all();

            $permission->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('role::permission.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('role/permission/' . $permission->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('role/permission/' . $permission->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the permission.
     *
     * @param Model   $permission
     *
     * @return Response
     */
    public function destroy(PermissionRequest $request, Permission $permission)
    {
        try {
            $permission->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('role::permission.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('role/permission/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('role/permission/' . $permission->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
