<?php

namespace Project\Role\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Project\Role\Interfaces\RoleRepositoryInterface;

class RolePublicController extends BaseController
{
    // use RoleWorkflow;

    /**
     * Constructor.
     *
     * @param type \Project\Role\Interfaces\RoleRepositoryInterface $role
     *
     * @return type
     */
    public function __construct(RoleRepositoryInterface $role)
    {
        $this->repository = $role;
        parent::__construct();
    }

    /**
     * Show role's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $roles = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('role::role.names'))
            ->view('role::public.role.index')
            ->data(compact('roles'))
            ->output();
    }


    /**
     * Show role.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $role = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($role->name . trans('role::role.name'))
            ->view('role::public.role.show')
            ->data(compact('role'))
            ->output();
    }

}
