<?php

namespace Project\Role\Policies;

use Litepie\User\Contracts\UserPolicy;
use Project\Role\Models\Label;

class LabelPolicy
{

    /**
     * Determine if the given user can view the label.
     *
     * @param UserPolicy $user
     * @param Label $label
     *
     * @return bool
     */
    public function view(UserPolicy $user, Label $label)
    {
        if ($user->canDo('role.label.view') && $user->isAdmin()) {
            return true;
        }

        return $label->user_id == user_id() && $label->user_type == user_type();
    }

    /**
     * Determine if the given user can create a label.
     *
     * @param UserPolicy $user
     * @param Label $label
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('role.label.create');
    }

    /**
     * Determine if the given user can update the given label.
     *
     * @param UserPolicy $user
     * @param Label $label
     *
     * @return bool
     */
    public function update(UserPolicy $user, Label $label)
    {
        if ($user->canDo('role.label.edit') && $user->isAdmin()) {
            return true;
        }

        return $label->user_id == user_id() && $label->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given label.
     *
     * @param UserPolicy $user
     * @param Label $label
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Label $label)
    {
        return $label->user_id == user_id() && $label->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given label.
     *
     * @param UserPolicy $user
     * @param Label $label
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Label $label)
    {
        if ($user->canDo('role.label.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given label.
     *
     * @param UserPolicy $user
     * @param Label $label
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Label $label)
    {
        if ($user->canDo('role.label.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
